Crate tiny_ping

Crate tiny_ping 

Structs

ER1
EchoReply
EchoReply struct, which contains some packet information.
EchoRequest
IcmpV4
IcmpV6
IpV4Packet
PingAttempt
One attempt in a repeated ping series.
PingRequest
A single ICMP echo request.
PingResult
PingSeries
A sequence of ICMP echo requests.
PingSeriesResult
Results and aggregate statistics for a repeated ping series.
PingSummary
Aggregate statistics for a repeated ping series.
Pinger
A Ping struct represents the state of one particular ping instance.

Enums

Error
An error resulting from a ping option-setting or send/receive operation.
IpV4Protocol
SocketType

Constants

ICMP_HEADER_SIZE