PingRequest

Struct PingRequest 

pub struct PingRequest { /* private fields */ }
A single ICMP echo request.

Implementations

Source

impl PingRequest

pub fn new(sequence: u16) -> Self

Creates a request with a sequence number and the pinger’s default payload.

pub fn payload(self, payload: impl Into<Vec<u8>>) -> Self

Uses exact bytes as the ICMP echo payload for this request.

pub fn sequence(&self) -> u16

Returns the ICMP sequence number.

pub fn payload_bytes(&self) -> Option<&[u8]>

Returns the custom payload bytes, if this request has one.