pub struct PingRequest { /* private fields */ }Expand description
A single ICMP echo request.
Implementations
Sourceimpl PingRequest
impl PingRequest
Sourcepub fn new(sequence: u16) -> Self
pub fn new(sequence: u16) -> Self
Creates a request with a sequence number and the pinger’s default payload.
Sourcepub fn payload(self, payload: impl Into<Vec<u8>>) -> Self
pub fn payload(self, payload: impl Into<Vec<u8>>) -> Self
Uses exact bytes as the ICMP echo payload for this request.
Sourcepub fn payload_bytes(&self) -> Option<&[u8]>
pub fn payload_bytes(&self) -> Option<&[u8]>
Returns the custom payload bytes, if this request has one.